<?xml version="1.0" ?><!DOCTYPE TS><TS language="nb" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="641"/>
        <source>select-area</source>
        <translation>velg-område</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="986"/>
        <location filename="../mainwindow.cpp" line="988"/>
        <location filename="../mainwindow.cpp" line="1246"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="1262"/>
        <location filename="../mainwindow.cpp" line="1265"/>
        <location filename="../mainwindow.cpp" line="1302"/>
        <location filename="../mainwindow.cpp" line="1305"/>
        <location filename="../mainwindow.cpp" line="1337"/>
        <location filename="../mainwindow.cpp" line="1340"/>
        <source>DeepinScreenshot</source>
        <translation>DeepinSkjermbilde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1004"/>
        <location filename="../mainwindow.cpp" line="1366"/>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1018"/>
        <location filename="../mainwindow.cpp" line="1386"/>
        <source>Picture has been saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1270"/>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1360"/>
        <source>Save failed. Please save it in your home directory.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1384"/>
        <source>Picture has been saved to clipboard</source>
        <translation>Bildet har blitt lagt til utklippstavle </translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <location filename="../controller/menucontroller.cpp" line="40"/>
        <source>Rectangle</source>
        <translation>Rektangel</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="48"/>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="56"/>
        <source>Arrow</source>
        <translation>Pil</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="64"/>
        <source>Pencil</source>
        <translation>Blyant</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="72"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="80"/>
        <source>Undo</source>
        <translation>Angre</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="96"/>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="99"/>
        <source>Save to desktop</source>
        <translation>Lagre til skrivebordet</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="100"/>
        <source>Autosave</source>
        <translation>Lagre automatisk</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="101"/>
        <source>Save to specified folder</source>
        <translation>Lagre til en spesifisert mappe</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="102"/>
        <source>Copy to clipboard</source>
        <translation>Kopier til utklippstavle </translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="103"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Lagre automatisk og kopier til utklippstavle</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="124"/>
        <source>Exit</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="78"/>
        <source>Deepin Screenshot will start after %1 seconds</source>
        <translation>Deepin Skjermbilde vil starte etter %1 sekunder</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../utils/shortcut.cpp" line="29"/>
        <source>Start/Screenshot</source>
        <translation>Start/Skjermbilde</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="30"/>
        <location filename="../utils/shortcut.cpp" line="41"/>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="31"/>
        <source>Painting</source>
        <translation>Maling</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="32"/>
        <source>Size Adjustment</source>
        <translation>Størrelsejustering</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="35"/>
        <source>Quick start</source>
        <translation>Rask start</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="36"/>
        <source>Full screenshot</source>
        <translation>Fullt skjermbilde</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="37"/>
        <source>Delay screenshot</source>
        <translation>Forsinket skjermbilde</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="38"/>
        <source>Undo</source>
        <translation>Angre</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="39"/>
        <source>Exit</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="42"/>
        <source>Copy to clipboard</source>
        <translation>Kopier til utklippstavle </translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="45"/>
        <source>Rectangle</source>
        <translation>Rektangel</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="46"/>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="47"/>
        <source>Arrow</source>
        <translation>Pil</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="48"/>
        <source>Pencil</source>
        <translation>Blyant</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="49"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="50"/>
        <source>Color</source>
        <translation>Farge</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="53"/>
        <source>Increase height up</source>
        <translation>Øk høyden opp</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="54"/>
        <source>Increase height down</source>
        <translation>Øk høyden ned</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="55"/>
        <source>Increase width left</source>
        <translation>Øk bredde venstre</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="56"/>
        <source>Increase width right</source>
        <translation>Øk bredde høyre</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="57"/>
        <source>Decrease height up</source>
        <translation>Mink høyden opp</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="58"/>
        <source>Decrease height down</source>
        <translation>Mink høyden ned</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="59"/>
        <source>Decrease width left</source>
        <translation>Mink bredde venstre</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="60"/>
        <source>Decrease width right</source>
        <translation>Mink bredde høyre</translation>
    </message>
</context>
<context>
    <name>SubToolBar</name>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="397"/>
        <source>Save to desktop</source>
        <translation>Lagre til skrivebordet</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="403"/>
        <source>Autosave</source>
        <translation>Lagre automatisk</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="409"/>
        <source>Save to specified folder</source>
        <translation>Lagre til en spesifisert mappe</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="415"/>
        <source>Copy to clipboard</source>
        <translation>Kopier til utklippstavle </translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="420"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Lagre automatisk og kopier til utklippstavle</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="425"/>
        <source>Low</source>
        <translation>Lav</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="439"/>
        <source>High</source>
        <translation>Høy</translation>
    </message>
</context>
</TS>